close all
clear all
clc

%% Importing Geometry
G=load('Vane_rid.mat');
ToothProfile=G.xyv_rid';
n=length(ToothProfile);

ToothProfileMatrix1=[ToothProfile(1,:);ToothProfile(2,:);-10*ones(1,n);ones(1,n)];
ToothProfileMatrix2=[ToothProfile(1,:);ToothProfile(2,:);25*ones(1,n);ones(1,n)];
ToothProfileMatrix3=[ToothProfile(1,:);ToothProfile(2,:);-1.25*ones(1,n);ones(1,n)];
ToothProfileMatrix4=[ToothProfile(1,:);ToothProfile(2,:);16.25*ones(1,n);ones(1,n)];
ToothProfileMatrix5=[ToothProfile(1,:);ToothProfile(2,:);7.5*ones(1,n);ones(1,n)];
ToothProfileMatrix1(2,:)=-ToothProfileMatrix1(2,:);
ToothProfileMatrix2(2,:)=-ToothProfileMatrix2(2,:);
ToothProfileMatrix3(2,:)=-ToothProfileMatrix3(2,:);
ToothProfileMatrix4(2,:)=-ToothProfileMatrix4(2,:);
ToothProfileMatrix5(2,:)=-ToothProfileMatrix5(2,:);

%% Defining Parameters
%%% number of teeth of the shaper
N_s=17;
%%% module
m=3;
%%% pressure angle
alpha=20;
%%% intersection angle
gamma=80;
%%% radii
r_ps  = N_s*m/2;                    %spur gear formula
r_p2 = 10*r_ps;                     %gear ratio of 10

%% Trajectory Matrix
TrajectoryMatrix1=zeros(4,n,100);    %100 angle iterations
TrajectoryMatrix2=zeros(4,n,100);    %100 angle iterations
TrajectoryMatrix3=zeros(4,n,100);    %100 angle iterations
TrajectoryMatrix4=zeros(4,n,100);    %100 angle iterations
TrajectoryMatrix5=zeros(4,n,100);    %100 angle iterations

for i=1:150
     Psi_s=i/2+50;
     Psi_2=Psi_s*r_ps/r_p2;
         M2m = [ cosd(Psi_2) sind(Psi_2) 0   0;
                -sind(Psi_2) cosd(Psi_2) 0   0;
                 0           0           1   0;
                 0           0           0   1];
       
         Mma = [-cosd(gamma)    0   sind(gamma)  r_p2            ;
                 0              1   0            0               ;
                -sind(gamma)    0  -cosd(gamma) -r_p2*cotd(gamma);
                 0              0   0            1               ];
         
         Mas = [ cosd(Psi_s)   -sind(Psi_s) 0   0;
                 sind(Psi_s)    cosd(Psi_s) 0   0;
                 0              0           1   0;
                 0              0           0   1];
                 
     TrajectoryMatrix1(:,:,i)=M2m*Mma*Mas*ToothProfileMatrix1;
     TrajectoryMatrix2(:,:,i)=M2m*Mma*Mas*ToothProfileMatrix2;
     TrajectoryMatrix3(:,:,i)=M2m*Mma*Mas*ToothProfileMatrix3;
     TrajectoryMatrix4(:,:,i)=M2m*Mma*Mas*ToothProfileMatrix4;
     TrajectoryMatrix5(:,:,i)=M2m*Mma*Mas*ToothProfileMatrix5;
end

%% Plotting
 plot3(TrajectoryMatrix1(1,:,1),TrajectoryMatrix1(2,:,1),TrajectoryMatrix1(3,:,1),'red')
 hold on
 plot3(TrajectoryMatrix2(1,:,1),TrajectoryMatrix2(2,:,1),TrajectoryMatrix2(3,:,1),'red')
 hold on
for i=1:n-1
fill3([TrajectoryMatrix1(1,i,1) TrajectoryMatrix1(1,i+1,1) TrajectoryMatrix2(1,i+1,1) TrajectoryMatrix2(1,i,1)], [TrajectoryMatrix1(2,i,1) TrajectoryMatrix1(2,i+1,1) TrajectoryMatrix2(2,i+1,1) TrajectoryMatrix2(2,i,1)], [TrajectoryMatrix1(3,i,1) TrajectoryMatrix1(3,i+1,1) TrajectoryMatrix2(3,i+1,1) TrajectoryMatrix2(3,i,1)], 'r')
end
 
 for j=2:150
     plot3(TrajectoryMatrix1(1,:,j),TrajectoryMatrix1(2,:,j),TrajectoryMatrix1(3,:,j),'black')
     hold on
     plot3(TrajectoryMatrix2(1,:,j),TrajectoryMatrix2(2,:,j),TrajectoryMatrix2(3,:,j),'black')
     hold on
     plot3(TrajectoryMatrix3(1,:,j),TrajectoryMatrix3(2,:,j),TrajectoryMatrix3(3,:,j),'black')
     hold on
     plot3(TrajectoryMatrix4(1,:,j),TrajectoryMatrix4(2,:,j),TrajectoryMatrix4(3,:,j),'black')
     hold on
     plot3(TrajectoryMatrix5(1,:,j),TrajectoryMatrix5(2,:,j),TrajectoryMatrix5(3,:,j),'black')
     hold on
          axis equal
          
           for i=1:100:n
     plot3([TrajectoryMatrix1(1,i,j) TrajectoryMatrix2(1,i,j)],[TrajectoryMatrix1(2,i,j) TrajectoryMatrix2(2,i,j)],[TrajectoryMatrix1(3,i,j) TrajectoryMatrix2(3,i,j)],'Color',[0 0 0]+0.5)
     hold on
           end
%       for i=1:n-1
%       fill3([TrajectoryMatrix1(1,i,j) TrajectoryMatrix1(1,i+1,j) TrajectoryMatrix2(1,i+1,j) TrajectoryMatrix2(1,i,j)], [TrajectoryMatrix1(2,i,j) TrajectoryMatrix1(2,i+1,j) TrajectoryMatrix2(2,i+1,j) TrajectoryMatrix2(2,i,j)], [TrajectoryMatrix1(3,i,j) TrajectoryMatrix1(3,i+1,j) TrajectoryMatrix2(3,i+1,j) TrajectoryMatrix2(3,i,j)], 'b')
%       end
 end
  axis equal
