function [gear]= CutTeeth (gear,rack)
Z=gear.params.z;
shift=gear.params.shift_coeff*rack.m*cos(rack.beta);
rp=Z*rack.m/2;
rg=rp*gear.params.ratio;

ang=360/Z*3;

figure(77); hold on; axis equal;
for ik=1:length(rack.RackpointsCell)
    plot(rack.RackpointsCell{ik}(:,1),rack.RackpointsCell{ik}(:,2));
end

nst=551; % Number of angular postions in which the cut process is simulated
nump=600; % Number of interpolation points for the various segments
thresholdI=0.08; % [mm] threshold for the point of intersection

[invol]=involSegm(rack.RackpointsCell,rack);
invseg=[];
segment=1;

% filename = 'provataagliomod2.gif';
% tstep=1/30;
% rack.RackpointsCell{1}=cell2mat(rack.RackpointsCell');

fighandle=figure(125+gear.number); fig.params.fighandle=fighandle;

for seg=1:size(rack.RackpointsCell,2)
    
    % Interpolation of the segment of the rack to increase the number of
    % generating points
    Xi=(linspace(rack.RackpointsCell{seg}(1,1),rack.RackpointsCell{seg}(end,1),nump))';
    Yi=interp1(rack.RackpointsCell{seg}(:,1),rack.RackpointsCell{seg}(:,2),Xi,'linear')+rp+shift;
    %     Xi=rack.RackpointsCell{1}(:,1);
    %     Yi=rack.RackpointsCell{1}(:,2)+rp+shift;
    Famx(:,1)=Xi;
    Famy(:,1)=Yi;
    
    if seg == 2 || seg == size(rack.RackpointsCell,2)-1 % fillets
        if rack.alphaprP0 >0
            molt=ceil(rack.alpha-rack.alphaprP0);
            if molt < 5, molt=5; end
        else
            molt=5;
        end
        angl=linspace(ang,-ang,nst*molt);
    else
        molt=1;
        angl=linspace(ang,-ang,nst);
    end
    P=[0 rp]; % Invariant point I (see Litvin p.120 fig 6.9.2)
    inim=NaN;
    
    for i=1:length(angl)
        % Motion of the rack cutter: Translation
        Trasl=[Xi+rp*angl(i)*pi/180,Yi];
        Famx(:,i)=Trasl(:,1);
        Famy(:,i)=Trasl(:,2);
        
        % Normals of the generating rack cutter
        N=LineNormals2D(Trasl);
        
        % Analytical expression of the normal lines passing through each point
        %--------------------------------------
        % y= Mx+Q
        Xr=Trasl(:,1); Yr=Trasl(:,2);
        d=-N(:,1).*Xr-N(:,2).*Yr;
        M=(N(:,2)./N(:,1));
        Q=Yi-M.*Xr;
        
        [idvert,~]=find(isinf(M)); % for vertical normals
        
        % Intersection of the normal lines of the cutter with the invariant
        % point I (see Litvin p.120 fig 6.9.2)
        yp=P(2);
        xp=(yp-Q)./M;
        
        
        xp(idvert)=Xr(idvert); % for vertical normals
        %--------------------------------------
        
        % Find the point of intersection which is closer to I
        dist=sqrt((xp-P(1)).^2+(yp-P(2)).^2);
        [mindist(i),inim(i)]=min(dist);
        if mindist(i) > thresholdI
            inim(i)=NaN;
        end
        
        % Motion of the gear: Rotation
        rotat=rotation([Famx(:,i),Famy(:,i)], [0 0],angl(i),'degrees');
        Famx(:,i)=rotat(:,1);
        Famy(:,i)=rotat(:,2);
        
    end % End of the loop on the angular positions for the current segment
    
    
    % --------------- Plot of the generation ----------------------------------
    figure(fig.params.fighandle); axis equal; hold on; grid on;
    for i=1:5*molt:size(angl,2)
        if i==1
            % plot(Xi,Yi,'r','LineWidth',2)
            plot(Famx(:,i),Famy(:,i),'r','LineWidth',2)
            %             xlim([-51.507811143243025,51.507811143243025]);
            %             ylim([75.82073571246437,157.0701539351929])
            set(gcf,'Color',[1 1 1]);
        else
            plot(Famx(:,i),Famy(:,i),'k')
        end
        %     % Capture the plot as an image
        %     frame = getframe(fig.params.fighandle);
        %     im = frame2im(frame);
        %     [imind,cm] = rgb2ind(im,256,'nodither');
        %     % Write to the GIF File
        %     if i == 1
        %         imwrite(imind,cm,filename,'gif', 'Loopcount',inf,'DelayTime',tstep);
        %     else
        %         imwrite(imind,cm,filename,'gif','WriteMode','append','DelayTime',tstep);
        %     end
    end
    
    
    %     figure(125); hold on; axis equal;
    %     for i=1:size(Famx,2)
    %         if not(isnan(inim(i)))
    %             plot(Famx(inim(i),i),Famy(inim(i),i),'ob');
    %         end
    %     end
    % -------------------------------------------------------------------------
    
    if not(all(isnan(inim)))
        % Cartesian coordinates of the generated points
        cont=1;
        for i=1:size(angl,2)
            if not(isnan(inim(i)))
                Genxy{segment}(cont,:)=[Famx(inim(i),i),Famy(inim(i),i)];
                cont=cont+1;
            end
        end
        
        % Conversion to polar
        [Genrt{segment}(:,2),Genrt{segment}(:,1)]=cart2pol(Genxy{segment}(:,1),Genxy{segment}(:,2));
        
        % Save the segment number of the involute
        if seg == invol(1)
            invseg(1)=segment;
        elseif seg == invol(2)
            invseg(2)=segment;
        end
        
        segment=segment+1;
        
    else
        continue
    end
    %     % Sort by increasing angle
    %     [~,idsort]=sort(Genrt{seg}(:,2));
    %     Genrt{seg}=Genrt{seg}(idsort,:);
    %     Genxy{seg}=Genxy{seg}(idsort,:);
    
    %     % Sort by increasing radius
    %     [~,idsort]=sort(Genrt{seg}(:,1));
    %     Genrt{seg}=Genrt{seg}(idsort,:);
    %     Genxy{seg}=Genxy{seg}(idsort,:);
    
end % End of the loop of the segments

% % -------------------------------------------------------------------------
% % Improve the quality of the fillet and join with the other adjacent
% % segments. In case there is a protuberance the number of points generated
% % by the fillet portion of the rack is severely limited and can yield poor
% % results in terms of visual quality of the fillet
% % Left fillet
% [~,sta]=min(Genrt{1}(:,2));
% [~,fin]=max(Genrt{3}(:,2));
% figure(77);hold on; plot(unique([Genxy{1}(sta,1);Genxy{2}(:,1);Genxy{3}(fin,1)],'stable'),...
%     unique([Genxy{1}(sta,2);Genxy{2}(:,2);Genxy{3}(fin,2)]),':*'),axis equal;
% xq=linspace(Genxy{1}(sta,1),Genxy{3}(fin,1),round(nump/3))';
% [pyq,S,mu]=polyfit(unique([Genxy{1}(sta,1);Genxy{2}(:,1);Genxy{3}(fin,1)],'stable'),...
%     unique([Genxy{1}(sta,2);Genxy{2}(:,2);Genxy{3}(fin,2)],'stable'),2);
% [yq,delta] = polyval(pyq,xq,S,mu);
% Genxy{2}=[xq,yq];
% Genrt{2}=[];
% [Genrt{2}(:,2),Genrt{2}(:,1)]=cart2pol(xq,yq);

if isempty(invseg)
    warning('The generated tooth does not have an involute portion. Carefully check your input data.');
end

 figure(77+gear.number); hold on; axis equal;
 for ik=1:length(Genrt)
     plot(Genxy{ik}(:,1),Genxy{ik}(:,2));
 end

%
% figure(78); hold on; axis equal;
% % Remove intersecting segments
% for ik=1:length(Genxy)-1
%     % Check if there is intersection between adjacent (consecutive)
%     % segments
% %     ivp2=1:length(Genxy); ivp2(ik)=[];
%
%     %     for ik2=ivp2
%     ik2=ik+1;
%     if size(Genxy{ik},1) >=2 && size(Genxy{ik2},1) >=2
%         [x0,y0,iout,jout] = intersections2(Genxy{ik}(:,1),Genxy{ik}(:,2),...
%             Genxy{ik2}(:,1),Genxy{ik2}(:,2));
%
%         if not(isempty(x0))
%             if ik== 7, keyboard, end
%             [t0,r0]=cart2pol(x0,y0);
%             [~,itp]=min(r0);
%             inters=[x0(itp),y0(itp)];
%             [interspol(1,2),interspol(1,1)]=cart2pol(inters(1,1),inters(1,2));
%
%
%             %---------- plot only ---------------------------------------
%                     plot(x0,y0,'x');
%                     plot(x0(itp),y0(itp),'*r')
%                     plot(Genxy{ik}(iout(itp),1),Genxy{ik}(iout(itp),2),'pk')
%                     plot(Genxy{ik2}(jout(itp),1),Genxy{ik2}(jout(itp),2),'pb')
%             %------------------------------------------------------------
%             %                 keyboard
%
%
%             if iout(itp)>size(Genxy{ik},1)/2 %ik<=length(Genxy)/2
%                 Genxy{ik}(iout(itp):end,:)=[];
%                 Genxy{ik}(end+1,:)=inters;
%                 Genrt{ik}(iout(itp):end,:)=[];
%                 Genrt{ik}(end+1,:)=interspol;
%             else
%                 Genxy{ik}(1:iout(itp),:)=[];
%                 Genxy{ik}(1,:)=inters;
%                 Genrt{ik}(1:iout(itp),:)=[];
%                 Genrt{ik}(1,:)=interspol;
%             end
%
%             if jout(itp)>size(Genxy{ik2},1)/2 %ik2>=length(Genxy)/2
%                 Genxy{ik2}(jout(itp):end,:)=[];
%                 Genxy{ik2}(end+1,:)=inters;
%                 Genrt{ik2}(jout(itp):end,:)=[];
%                 Genrt{ik2}(end+1,:)=interspol;
%             else
%                 Genxy{ik2}(1:jout(itp),:)=[];
%                 Genxy{ik2}(1,:)=inters;
%                 Genrt{ik2}(1:jout(itp),:)=[];
%                 Genrt{ik2}(1,:)=interspol;
%             end
%
%
%         else
%             continue
%         end
%     end
%     %     end
% end
% for ika=1:length(Genxy)
%     plot(Genxy{ika}(:,1),Genxy{ika}(:,2));
% end

for ik=1:length(Genxy)-1
    % Check if there is intersection between adjacent (consecutive)
    % segments
    ivp2=1:length(Genxy); ivp2(ik)=[];
    
    for ik2=ivp2
        %     ik2=ik+1;
        if size(Genxy{ik},1) >=2 && size(Genxy{ik2},1) >=2
            [x0,y0,iout,jout] = intersections2(Genxy{ik}(:,1),Genxy{ik}(:,2),...
                Genxy{ik2}(:,1),Genxy{ik2}(:,2));
            
            if not(isempty(x0))
                %             if ik== 7, keyboard, end
                [t0,r0]=cart2pol(x0,y0);
                [~,itp]=min(r0);
                inters=[x0(itp),y0(itp)];
                [interspol(1,2),interspol(1,1)]=cart2pol(inters(1,1),inters(1,2));
                
                
                %             %---------- plot only ---------------------------------------
                %                     plot(x0,y0,'x');
                %                     plot(x0(itp),y0(itp),'*r')
                %                     plot(Genxy{ik}(iout(itp),1),Genxy{ik}(iout(itp),2),'pk')
                %                     plot(Genxy{ik2}(jout(itp),1),Genxy{ik2}(jout(itp),2),'pb')
                %             %------------------------------------------------------------
                %   keyboard
                
                
                if iout(itp)>1 && iout(itp)<size(Genxy{ik},1)
                    Genxy{ik}=[Genxy{ik}(1:iout(itp),:); inters; Genxy{ik}(iout(itp):end,:)];
                    Genrt{ik}=[Genrt{ik}(1:iout(itp),:); interspol; Genrt{ik}(iout(itp):end,:)];
                elseif iout(itp) == 1
                    Genxy{ik}= [inters; Genxy{ik}];
                    Genrt{ik}= [interspol; Genrt{ik}];
                elseif iout(itp)==size(Genxy{ik},1)
                    Genxy{ik}=[Genxy{ik}; inters];
                    Genrt{ik}= [Genrt{ik}; interspol];
                end
                
                if jout(itp)>1 && jout(itp)<size(Genxy{ik2},1)
                    Genxy{ik2}=[Genxy{ik2}(1:jout(itp),:); inters; Genxy{ik2}(jout(itp):end,:)];
                    Genrt{ik2}=[Genrt{ik2}(1:jout(itp),:); interspol; Genrt{ik2}(jout(itp):end,:)];
                elseif jout(itp) ==1
                    Genxy{ik2}= [inters; Genxy{ik2}];
                    Genrt{ik2}= [interspol; Genrt{ik2}];
                elseif jout(itp)==size(Genxy{ik2},1)
                    Genxy{ik2}=[Genxy{ik2}; inters];
                    Genrt{ik2}= [Genrt{ik2}; interspol];
                end
                
            else
                continue
            end
        end
    end
end


% all points in polar coordinates in 2 columns array
RT=cell2mat(Genrt');
rmin=min(RT(:,1));
rmax=max(RT(:,1));
% rvet=linspace(rmin,rmax,nump*2);


% Divide left and right sides
[rightid,~]=find(RT(:,2)<=pi/2);
leftid=(1:size(RT,1))';
leftid(rightid)=[];

rightf=RT(rightid,:);
leftf=RT(leftid,:);

rtip=(Z*rack.m)/2+rack.hf*rack.m*cos(rack.beta)+shift;

% pick the last straight segment for the two sides
% if abs(rack.ca) > 0
%     L=Genxy{size(Genxy,2)/2-2};
%     R=Genxy{size(Genxy,2)/2+3};
% else
%     L=Genxy{size(Genxy,2)/2-1};
%     R=Genxy{size(Genxy,2)/2+2};
% end

pointed=0;
cop=1; rtip_int=[];
for ilf=3:size(Genxy,2)/2
    %     for ilr=size(Genxy,2)/2+1:size(Genxy,2)-2
    ilr=size(Genxy,2)-ilf+1;
    L=Genxy{ilf};
    R=Genxy{ilr};
    % [L(:,1),L(:,2)]=pol2cart(RT(1:size(RT)/2,2),RT(1:size(RT)/2,1));
    % [R(:,1),R(:,2)]=pol2cart(RT(size(RT)/2+1:end,2),RT(size(RT)/2+1:end,1));
    
    [x0,y0,iout,jout] = intersections2(L(:,1),L(:,2),R(:,1),R(:,2));
    [ti,ri]=cart2pol(x0,y0);
    
    if y0>0
    if min(ri) < rtip
        warning('Tooth is pointed.')
        pointed=1;
        figure(78); hold on, axis equal;
        plot(L(:,1),L(:,2),'-.b'); plot(R(:,1),R(:,2),'-.r');
        plot(x0,y0,'*k');
        plot(0,rtip,'pm')
        rtip_int(cop)=min(ri);
        cop=cop+1;
    end
    end
    %     end
    %     if pointed
    %         break
    %     end
end

if pointed
    rtip=min(rtip_int);
end

rightf(rightf(:,1)>=rtip,:)=[];
leftf(leftf(:,1)>=rtip,:)=[];


% clear rightf; rightf=rvet';

[~,iso]=sort(rightf(:,1));
rightf=rightf(iso,:);

[~,isol]=sort(leftf(:,1));
leftf=leftf(isol,:);


% To remove wrong points exclude the tip and root circles since they have
% the same radii and this causes a lot of problems tu understand the real
% points that need to be considered in the flank. They will be re-added
% later

% This process could be done only once for symmetric profiles, but it's
% better to do it now
% right flank: exclude all the left flank and the first one after and the
% last
if rack.rhoa == rack.rhoamax
    exclude_r=[1:length(Genrt)/2+1];
else
exclude_r=[1:length(Genrt)/2+1,length(Genrt)];
end
include_r=1:length(Genrt); include_r(exclude_r)=[];
% left flank: exclude the first and from the one before the middle to the
% end
if rack.rhoa == rack.rhoamax
exclude_l=[length(Genrt)/2:length(Genrt)];
else
exclude_l=[1,length(Genrt)/2:length(Genrt)];
end
include_l=1:length(Genrt); include_l(exclude_l)=[];

% treat right flank -------------------------------------------------------
cont=1;
for ip=1:length(rightf)
    contin=1;
    rtent=[]; %if cont== 1186, keyboard, end
    for ic=include_r
        contin2=1;
        yv=[];
        % Intersect the current segment with an arc in polar coordinates
        [x0,yv,iout,jout] = intersections2(Genrt{ic}(:,1),Genrt{ic}(:,2),...
            [rightf(ip,1);rightf(ip,1)],[pi/2;0]);
        kdtreeobj = KDTreeSearcher(rightf,'distance','euclidean');
        %         figure(99); hold on; plot(Genrt{ic}(:,1),Genrt{ic}(:,2));
        %         plot([rightf(ip,1);rightf(ip,1)],[pi/2;0],'-.k')
        % store the intersection of the current segment
        if ~isempty(yv)
            if any(yv <= pi/2)
                %                 [xx,yy]=pol2cart(max(yv),rightf(ip,1));
                %                 [n1,dist] = knnsearch(kdtreeobj,[xx,yy],'k',1);
                %                 %[t,r]=cart2pol(rightf(n1,2),rightf(n1,1));
                %                 rtent(contin,:)=[rightf(n1,1),rightf(n1,2)];
                rtent(contin,:)=[rightf(ip,1),max(yv),ic];
                contin=contin+1;
            end
        end
        
    end
    
    % save the intersection needed between all found for the different
    % segments
    if ~isempty(rtent)
        [mv,idv]=max(rtent(:,2));
        rflank(cont,:)=rtent(idv,:);
        cont=cont+1;
    end
    rtent=[];
end


% treat left flank --------------------------------------------------------
cont=1;  ltent=[];
for ip=1:length(leftf)
    contin=1;
    
    for ic=include_l
        contin2=1;
        yv=[];
        % Intersect the current segment with an arc in polar coordinates
        [x0,yv,iout,jout] = intersections2(Genrt{ic}(:,1),Genrt{ic}(:,2),...
            [leftf(ip,1);leftf(ip,1)],[pi;pi/2]);
        %         kdtreeobj = KDTreeSearcher(rightf,'distance','euclidean');
        
        % store the intersection of the current segment
        if ~isempty(yv)
            if any(yv >= pi/2)
                %                 [xx,yy]=pol2cart(max(yv),rightf(ip,1));
                %                 [n1,dist] = knnsearch(kdtreeobj,[xx,yy],'k',1);
                %                 %[t,r]=cart2pol(rightf(n1,2),rightf(n1,1));
                %                 rtent(contin,:)=[rightf(n1,1),rightf(n1,2)];
                ltent(contin,:)=[leftf(ip,1),min(yv),ic];
                contin=contin+1;
            end
        end
        
    end
    
    % save the intersection needed between all found for the different
    % segments
    if ~isempty(ltent)
        [mv,idv]=min(ltent(:,2));
        lflank(cont,:)=ltent(idv,:);
        cont=cont+1;
    end
    ltent=[];
end


[xr,yr]=pol2cart(rflank(:,2),rflank(:,1));
[xl,yl]=pol2cart(lflank(:,2),lflank(:,1));
figure(125+gear.number);hold on;
% plot(xr,yr,'--','LineWidth',2); axis equal;
% plot(xl,yl,'--','LineWidth',2);

xl_flank=[xl,yl];
xr_flank=[xr,yr];

% The points of the flanks are sorted in growing radius, so to have
% continuity i flip up/down the right flank
rflank(:,:)= flipud(rflank(:,:));
xr_flank(:,:)= flipud(xr_flank(:,:));

% Creation of the root circle ---------------------------------------------
% Left side
maxl=max(lflank(:,2));
halfl=((2*pi)/Z)/2+pi/2;
rl=ones(nump/100,1)*min(Genrt{1}(:,1));
al=linspace(halfl,maxl,nump/100)';
lroot=[rl,al];

% Right side
maxr=min(rflank(:,2));
halfr=-((2*pi)/Z)/2+pi/2;
rr=ones(nump/100,1)*min(Genrt{end}(:,1));
ar=linspace(maxr,halfr,nump/100)';
rroot=[rr,ar];

[xr_root,yr_root]=pol2cart(rroot(:,2),rroot(:,1));
[xl_root,yl_root]=pol2cart(lroot(:,2),lroot(:,1));

plot(xr_root,yr_root,'-b','LineWidth',3); axis equal;
plot(xl_root,yl_root,'-b','LineWidth',3);


linterspol=[];
% Define the fillet beginning locus
% Left flank  -------------------------------------------------------------
% In case there is a protuberance check the intersections
if and(rack.alphaprP0>0,rack.alphaprP0<rack.alpha) && rack.hprP0 >0
    cont=1;
    for ik=include_l
        % Check if there is intersection between segments
        ivp2=include_l; ivp2(ivp2==ik)=[];
        
        for ik2=ivp2
            
            if size(Genxy{ik},1) >=2 && size(Genxy{ik2},1) >=2
                [x0,y0,iout,jout] = intersections2(Genxy{ik}(:,1),Genxy{ik}(:,2),...
                    Genxy{ik2}(:,1),Genxy{ik2}(:,2));
                
                if not(isempty(x0))
                    
                    [t0,r0]=cart2pol(x0,y0);
                    [~,itp]=min(r0);
                    linters(cont,:)=[x0(itp),y0(itp)];
                    [linterspol(cont,2),linterspol(cont,1)]=cart2pol(linters(cont,1),linters(cont,2));
                    cont=cont+1;
                    
                else
                    continue
                end
            end
        end
    end
    
    if isempty(linterspol)
        linterspol=max(Genrt{2}(:,1));
    end
    
else
    
    %     cont=1;
    %     for ik=include_l
    %         % Check if there is intersection between segments
    %         ivp2=include_l; ivp2(ivp2==ik)=[];
    %
    %         for ik2=ivp2
    %
    %             if size(Genxy{ik},1) >=2 && size(Genxy{ik2},1) >=2
    %                 [x0,y0,iout,jout] = intersections2(Genxy{ik}(:,1),Genxy{ik}(:,2),...
    %                     Genxy{ik2}(:,1),Genxy{ik2}(:,2));
    %
    %                 if not(isempty(x0))
    %
    %                     [t0,r0]=cart2pol(x0,y0);
    %                     [~,itp]=min(r0);
    %                     linters(cont,:)=[x0(itp),y0(itp)];
    %                     [linterspol(cont,2),linterspol(cont,1)]=cart2pol(linters(cont,1),linters(cont,2));
    %                     cont=cont+1;
    %
    %                 else
    %                     continue
    %                 end
    %             end
    %         end
    %     end
    
    if isempty(linterspol)
        linterspol=max(Genrt{invseg(1)-1}(:,1));
    end
end

minl=min(linterspol(:,1));
[~,idml]=min(abs(lflank(:,1)-minl));
lfillet=lflank(1:idml,:);
if idml<length(lflank)
lflank(1:idml+1,:)=[];
end

rinterspol=[];
% Right flank -------------------------------------------------------------
if and(rack.alphaprP0>0,rack.alphaprP0<rack.alpha) && rack.hprP0 >0
    cont=1;
    for ik=include_r
        % Check if there is intersection between segments
        ivp2=include_r; ivp2(ivp2==ik)=[];
        
        for ik2=ivp2
            
            if size(Genxy{ik},1) >=2 && size(Genxy{ik2},1) >=2
                [x0,y0,iout,jout] = intersections2(Genxy{ik}(:,1),Genxy{ik}(:,2),...
                    Genxy{ik2}(:,1),Genxy{ik2}(:,2));
                
                if not(isempty(x0))
                    
                    [t0,r0]=cart2pol(x0,y0);
                    [~,itp]=min(r0);
                    rinters(cont,:)=[x0(itp),y0(itp)];
                    [rinterspol(cont,2),rinterspol(cont,1)]=cart2pol(rinters(cont,1),rinters(cont,2));
                    cont=cont+1;
                    
                else
                    continue
                end
            end
        end
    end
    
    if isempty(rinterspol)
        rinterspol=max(Genrt{end-1}(:,1));
    end
else
    %     cont=1;
    %     for ik=include_r
    %         % Check if there is intersection between segments
    %         ivp2=include_r; ivp2(ivp2==ik)=[];
    %
    %         for ik2=ivp2
    %
    %             if size(Genxy{ik},1) >=2 && size(Genxy{ik2},1) >=2
    %                 [x0,y0,iout,jout] = intersections2(Genxy{ik}(:,1),Genxy{ik}(:,2),...
    %                     Genxy{ik2}(:,1),Genxy{ik2}(:,2));
    %
    %                 if not(isempty(x0))
    %
    %                     [t0,r0]=cart2pol(x0,y0);
    %                     [~,itp]=min(r0);
    %                     rinters(cont,:)=[x0(itp),y0(itp)];
    %                     [rinterspol(cont,2),rinterspol(cont,1)]=cart2pol(rinters(cont,1),rinters(cont,2));
    %                     cont=cont+1;
    %
    %                 else
    %                     continue
    %                 end
    %             end
    %         end
    %     end
    if isempty(rinterspol)
        rinterspol=max(Genrt{invseg(2)+1}(:,1));
    end
end

minr=min(rinterspol(:,1));
[~,idmr]=min(abs(rflank(:,1)-minr));
rfillet=rflank(idmr:end,:);
if idmr>1
rflank(idmr-1:end,:)=[];
end
% do the same to the cartesian coordinates
xl_fillet=xl_flank(1:idml,:);
if idml<length(xl_flank)
xl_flank(1:idml+1,:)=[];
end
xr_fillet=xr_flank(idmr:end,:);
if idmr>1
xr_flank(idmr-1:end,:)=[];
end
% % Check if the tooth is pointed ---------------
% % if max(lflank(:,1)) < rtip && max(rflank(:,1)) < rtip
% if min(lflank(:,2)) < pi/2+eps || max(rflank(:,2)) > pi/2-eps
%     warning('Tooth is pointed.')
%     pointed=1;
% else
%     pointed=0;
% end

if pointed
    % Add the intersection point to one of the sides
    lflank(end+1,:)=[rtip, pi/2];
    xl_flank(end+1,:)=[0 rtip];
    % check that both flanks have the same maximum radius because when
    % dividing the left and right flanks the top portion might miss a point
    if max(lflank(:,1)) > max(rflank(:,1))
        % the right flank is missing a point
        rflank=[lflank(end,:); rflank(:,:)];
        xr_flank=[xl_flank(end,:); xr_flank(:,:)];
    elseif max(rflank(:,1)) > max(lflank(:,1))
        % the left flank is missing a point
        lflank=[lflank(:,:); rflank(1,:)];
        xl_flank=[xl_flank(:,:); xr_flank(1,:)];
    end
    
    % the tooth is pointed so the tip circle is empty
    rtipc=[];
    xr_tipc=[]; yr_tipc=[];
else % the tooth is not pointed
    
    % Creation of the tip circle
    rtipc(:,1)=ones(nump,1)*max(rflank(:,1));
    rtipc(:,2)=linspace(min(lflank(:,2)),max(rflank(:,2)),nump)';
    [xr_tipc,yr_tipc]=pol2cart(rtipc(:,2),rtipc(:,1));
    
    plot(xr_tipc,yr_tipc,'-b','LineWidth',3); axis equal;
    
end

plot(xr_flank(:,1),xr_flank(:,2),'-b','LineWidth',3); axis equal;
plot(xl_flank(:,1),xl_flank(:,2),'-b','LineWidth',3);

plot(xr_fillet(:,1),xr_fillet(:,2),'-b','LineWidth',3); axis equal;
plot(xl_fillet(:,1),xl_fillet(:,2),'-b','LineWidth',3);

% Calculation of the top radius of the involute part of the profile -------
invflankl=find(lflank(:,3)==invseg(1));
[al,bl]=ismember(Genrt{invseg(1)}(:,1),unique(lflank(invflankl),'rows','stable'));
[ltop,idl]=max(Genrt{invseg(1)}(al,1));
invflankr=find(rflank(:,3)==invseg(2));
[ar,br]=ismember(Genrt{invseg(2)}(:,1),unique(rflank(invflankr),'rows','stable'));
[rtop,idr]=max(Genrt{invseg(2)}(ar,1));
[rtopcirc,idmax]=max([ltop,rtop]);
if idmax == 1
    %     bll=bl(al);
    atopcirc = Genrt{invseg(1)}(al(idl),2);
elseif idmax == 2
    %     brr=br(ar);
    atopcirc = Genrt{invseg(2)}(ar(idr),2);
end

% Finalize variables for output -------------------------------------------
clear Genrt Genxy
% Genrt=[{unique(lroot,'rows','stable')},{unique(lfillet,'rows','stable')},...
%     {unique(lflank,'rows','stable')},{unique(rtipc,'rows','stable')},...
%     {unique(rflank,'rows','stable')},{unique(rfillet,'rows','stable')},...
%     {unique(rroot,'rows','stable')}];
% Genxy=[{unique([xl_root,yl_root],'rows','stable')},{unique(xl_fillet,'rows','stable')},...
%     {unique(xl_flank,'rows','stable')},{unique([xr_tipc,yr_tipc],'rows','stable')},...
%     {unique(xr_flank,'rows','stable')},{unique(xr_fillet,'rows','stable')},...
%     {unique([xr_root,yr_root],'rows','stable')}];

tolval=1e-3;
% left root circle --------- bottom to top
[rootl,idrootl,~]=uniquetol([xl_root,yl_root],tolval,'ByRows',1);
[~,id1]=sort(rootl(:,2),'ascend');
rootl=rootl(id1,:);
idrootl=idrootl(id1);
% Left fillet
[filletl,idfilletl,~]=uniquetol(xl_fillet,tolval,'ByRows',1);
[~,id2]=sort(filletl(:,2),'ascend');
filletl=filletl(id2,:);
idfilletl=idfilletl(id2);
% Left flank
[flankl,idflankl,~]=uniquetol(xl_flank,tolval,'ByRows',1);
[~,id3]=sort(flankl(:,2),'ascend');
flankl=flankl(id3,:);
idflankl=idflankl(id3);
% Tip circle --------- left to right
[tip,idtip,~]=uniquetol([xr_tipc,yr_tipc],tolval,'ByRows',1);
[~,id4]=sort(tip(:,1),'ascend');
tip=tip(id4,:);
idtip=idtip(id4);
% Right flank ------------- top to bottom
[flankr,idflankr,~]=uniquetol(xr_flank,tolval,'ByRows',1);
[~,id5]=sort(flankr(:,2),'descend');
flankr=flankr(id5,:);
idflankr=idflankr(id5);
% Right fillet
[filletr,idfilletr,~]=uniquetol(xr_fillet,tolval,'ByRows',1);
[~,id6]=sort(filletr(:,2),'descend');
filletr=filletr(id6,:);
idfilletr=idfilletr(id6);
% Right root circle
[rootr,idrootr,~]=uniquetol([xr_root,yr_root],tolval,'ByRows',1);
[~,id7]=sort(rootr(:,2),'descend');
rootr=rootr(id7,:);
idrootr=idrootr(id7);

Genxy=[{rootl},{filletl},{flankl},{tip},{flankr},{filletr},{rootr}];
Genrt=[{lroot(idrootl,:)},{lfillet(idfilletl,:)},{lflank(idflankl,:)},...
        {rtipc(idtip,:)},{rflank(idflankr,:)},{rfillet(idfilletr,:)},{rroot(idrootr,:)}];

gear.Genxy = Genxy;
gear.Genrt = Genrt;
gear.params.rtopcirc = rtopcirc;
gear.params.atopcirc = atopcirc;
gear.params.pointed = pointed;

figure(100); hold on; axis equal;
for ik=1:length(gear.Genxy)
    plot(Genxy{ik}(:,1),Genxy{ik}(:,2));
end

%%%%creating a vane instead of a tooth

%%% one segment
% gear.Genrt{1, 2}(:,3)=[];
% gear.Genrt{1, 3}(:,3)=[];
% gear.Genrt{1, 5}(:,3)=[];
% gear.Genrt{1, 6}(:,3)=[];
% Gen  = [gear.Genrt{1}' gear.Genrt{2}' gear.Genrt{3}' gear.Genrt{4}' gear.Genrt{5}' gear.Genrt{6}' gear.Genrt{7}']; 
% Gen2 = Gen;
% Gen2(2,:) = Gen2(2,:)-360/gear.params.z*pi()/180;
% Pinionrt=[Gen Gen2];
% Pinionrt(2,:)=Pinionrt(2,:)+0.5*360/gear.params.z*pi()/180;
% [Pinionxy(1,:),Pinionxy(2,:)]=pol2cart(Pinionrt(2,:),Pinionrt(1,:));
% m=length(gear.Genrt{1}(:,1))+length(gear.Genrt{2}(:,1))+length(gear.Genrt{3}(:,1))+0.5*length(gear.Genrt{4}(:,1));
% n=length(Pinionrt(1,:));
% Shaperxy=Pinionxy(:,m+1:n-m);
% [Shaperrt(2,:),Shaperrt(1,:)] = cart2pol(Shaperxy(1,:),Shaperxy(2,:));
% figure(1001); hold on; axis equal;
% plot(Shaperxy(1,:),Shaperxy(2,:));

%%%7 segments
Genrt_{1,1}=Genrt{1,1};
Genrt_{1,1}(:,2)=Genrt{1,1}(:,2)-360/gear.params.z*pi()/180;
Genrt_{1,2}=Genrt{1,2};
Genrt_{1,2}(:,2)=Genrt{1,2}(:,2)-360/gear.params.z*pi()/180;
Genrt_{1,3}=Genrt{1,3};
Genrt_{1,3}(:,2)=Genrt{1,3}(:,2)-360/gear.params.z*pi()/180;
Genrt_{1,4}=Genrt{1,4};
Genrt_{1,4}(:,2)=Genrt{1,4}(:,2)-360/gear.params.z*pi()/180;

m=length(Genrt{4}(:,1));
Shaperrt{1,1}=Genrt{4}(m/2+1:m,:);
Shaperrt{1,1}(:,2)=Shaperrt{1,1}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,1}(:,1),Shaperxy{1,1}(:,2)]=pol2cart(Shaperrt{1,1}(:,2),Shaperrt{1,1}(:,1));
Shaperrt{1,2}=Genrt{5};
Shaperrt{1,2}(:,2)=Shaperrt{1,2}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,2}(:,1),Shaperxy{1,2}(:,2)]=pol2cart(Shaperrt{1,2}(:,2),Shaperrt{1,2}(:,1));
Shaperrt{1,3}=Genrt{6};
Shaperrt{1,3}(:,2)=Shaperrt{1,3}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,3}(:,1),Shaperxy{1,3}(:,2)]=pol2cart(Shaperrt{1,3}(:,2),Shaperrt{1,3}(:,1));
Shaperrt{1,4}=[Genrt{7};Genrt_{1}];
Shaperrt{1,4}(:,2)=Shaperrt{1,4}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,4}(:,1),Shaperxy{1,4}(:,2)]=pol2cart(Shaperrt{1,4}(:,2),Shaperrt{1,4}(:,1));
Shaperrt{1,5}=Genrt_{2};
Shaperrt{1,5}(:,2)=Shaperrt{1,5}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,5}(:,1),Shaperxy{1,5}(:,2)]=pol2cart(Shaperrt{1,5}(:,2),Shaperrt{1,5}(:,1));
Shaperrt{1,6}=Genrt_{3};
Shaperrt{1,6}(:,2)=Shaperrt{1,6}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,6}(:,1),Shaperxy{1,6}(:,2)]=pol2cart(Shaperrt{1,6}(:,2),Shaperrt{1,6}(:,1));
Shaperrt{1,7}=Genrt_{4}(1:m/2,:);
Shaperrt{1,7}(:,2)=Shaperrt{1,7}(:,2)+0.5*360/gear.params.z*pi()/180;
[Shaperxy{1,7}(:,1),Shaperxy{1,7}(:,2)]=pol2cart(Shaperrt{1,7}(:,2),Shaperrt{1,7}(:,1));

figure(700); hold on; axis equal;
for ik=1:7
    plot(Shaperxy{ik}(:,1),Shaperxy{ik}(:,2));
end

fighandle=figure(130+gear.number); fig.params.fighandle=fighandle;
      
for seg=1:7
    if seg~=2||6
    Famx2=Shaperxy{seg}(:,1);
    Famy2=Shaperxy{seg}(:,2);
    
    angl=linspace(ang,-ang,nst);
    P=[0 rp]; % Invariant point I (see Litvin p.120 fig 6.9.2)
    inim=NaN;
       
    for i=1:length(angl)
        % Motion of the pinion cutter: Rotation
        Rotat1=rotation([Shaperxy{seg}(:,1),Shaperxy{seg}(:,2)], [0 0],angl(i),'degrees');
        Famx2(:,i)=Rotat1(:,1);
        Famy2(:,i)=Rotat1(:,2);
        
        % Normals of the generating rack cutter
        N=LineNormals2D(Rotat1);
               
        % Analytical expression of the normal lines passing through each point
        %--------------------------------------
        % y= Mx+Q
        Xr=Rotat1(:,1); Yr=Rotat1(:,2);
        d=-N(:,1).*Xr-N(:,2).*Yr;
        M=(N(:,2)./N(:,1));
        Q=Yr-M.*Xr;
        
        [idvert,~]=find(isinf(M)); % for vertical normals
        
        % Intersection of the normal lines of the cutter with the invariant
        % point I (see Litvin p.120 fig 6.9.2)
        yp=P(2);
        xp=(yp-Q)./M;
        xp(idvert)=Xr(idvert); % for vertical normals
        %--------------------------------------
        
        % Find the point of intersection which is closer to I
        dist=sqrt((xp-P(1)).^2+(yp-P(2)).^2);
        [mindist(i),inim(i)]=min(dist);
        if mindist(i) > thresholdI
            inim(i)=NaN;
        end
        
        % Motion of the gear: Rotation
        Rotat2=rotation([Famx2(:,i),Famy2(:,i)], [0 -rg+rp],-angl(i)/gear.params.ratio,'degrees');
        Famx2(:,i)=Rotat2(:,1);
        Famy2(:,i)=Rotat2(:,2);
        
    end % End of the loop on the angular positions for the current segment
        
     if not(all(isnan(inim)))
        % Cartesian coordinates of the generated points
        cont=1;
        for i=1:size(angl,2)
            if not(isnan(inim(i)))
                Genxy2{seg}(cont,:)=[Famx2(inim(i),i),Famy2(inim(i),i)];
                cont=cont+1;
            end
        end
     end

        % Conversion to polar
    Genxy2{seg}=sortrows(Genxy2{seg});   
    [Genrt2{seg}(:,2),Genrt2{seg}(:,1)]=cart2pol(Genxy2{seg}(:,1),Genxy2{seg}(:,2));
    
      % --------------- Plot of the generation ----------------------------------
    figure(fig.params.fighandle); axis equal; hold on; grid on;
    for i=1:8:size(angl,2)
        if i==1
            % plot(Xi,Yi,'r','LineWidth',2)
            plot(Famx2(:,i),Famy2(:,i),'r','LineWidth',2)
            %             xlim([-51.507811143243025,51.507811143243025]);
            %             ylim([75.82073571246437,157.0701539351929])
            set(gcf,'Color',[1 1 1]);
        else
            plot(Famx2(:,i),Famy2(:,i),'k')
        end
    end
    end
    % -------------------------------------------------------------------------   
end

seg=2;
cont=1;
vector=[1 1.1 1.2 1.3 1.4 1.5 1.6 1.7 1.8 1.9 2 2.2 2.4 2.6 2.8 3 3.3 3.6 4 5 6 8 10 12.5 15 17.5 20 22.5 25 27.5 30 32.5 35 37.5 40 42.5 45 47.5 50 52.5 55 57.5 60 62 65 68 69 70 71 72 73 74 75];
for k=1:length(vector)
    kk=vector(k);
    Famx2=Shaperxy{seg}(:,1);
    Famy2=Shaperxy{seg}(:,2);
    
    angl=linspace(ang,-ang,nst);
    P=[0 rp]; % Invariant point I (see Litvin p.120 fig 6.9.2)
    inim=NaN;
       
    for i=1:length(angl)
        % Motion of the pinion cutter: Rotation
        Rotat1=rotation([Shaperxy{seg}(:,1),Shaperxy{seg}(:,2)], [0 0],angl(i),'degrees');
        Famx2(:,i)=Rotat1(:,1);
        Famy2(:,i)=Rotat1(:,2);
        
        % Normals of the generating rack cutter
        N=LineNormals2D(Rotat1);
               
        % Analytical expression of the normal lines passing through each point
        %--------------------------------------
        % y= Mx+Q
        Xr=Rotat1(:,1); Yr=Rotat1(:,2);
        d=-N(:,1).*Xr-N(:,2).*Yr;
        M=(N(:,2)./N(:,1));
        M(1)=M(1)*kk;
        Q=Yr-M.*Xr;
        
        [idvert,~]=find(isinf(M)); % for vertical normals
        
        % Intersection of the normal lines of the cutter with the invariant
        % point I (see Litvin p.120 fig 6.9.2)
        yp=P(2);
        xp=(yp-Q)./M;
        xp(idvert)=Xr(idvert); % for vertical normals
        %--------------------------------------
        
        % Find the point of intersection which is closer to I
        dist=sqrt((xp-P(1)).^2+(yp-P(2)).^2);
        [mindist(i),inim(i)]=min(dist);
        if mindist(i) > thresholdI
            inim(i)=NaN;
        end
        
        % Motion of the gear: Rotation
        Rotat2=rotation([Famx2(:,i),Famy2(:,i)], [0 -rg+rp],-angl(i)/gear.params.ratio,'degrees');
        Famx2(:,i)=Rotat2(:,1);
        Famy2(:,i)=Rotat2(:,2);
        
    end % End of the loop on the angular positions for the current segment
        
     if not(all(isnan(inim)))
        % Cartesian coordinates of the generated points
        for i=1:size(angl,2)
            if not(isnan(inim(i)))
                Genxy2{seg}(cont,:)=[Famx2(inim(i),i),Famy2(inim(i),i)];
                cont=cont+1;
            end
        end
     end
    
      % --------------- Plot of the generation ----------------------------------
    figure(fig.params.fighandle); axis equal; hold on; grid on;
    for i=1:8:size(angl,2)
        if i==1
            % plot(Xi,Yi,'r','LineWidth',2)
            plot(Famx2(:,i),Famy2(:,i),'r','LineWidth',2)
            %             xlim([-51.507811143243025,51.507811143243025]);
            %             ylim([75.82073571246437,157.0701539351929])
            set(gcf,'Color',[1 1 1]);
        else
            plot(Famx2(:,i),Famy2(:,i),'k')
        end
    end
end
Genxy2{2}=unique(Genxy2{2},'rows');
Genxy2{2}=sortrows(Genxy2{2});
        % Conversion to polar of seg2|6
 Genrt2{2}=[];
[Genrt2{2}(:,2),Genrt2{2}(:,1)]=cart2pol(Genxy2{2}(:,1),Genxy2{2}(:,2));

seg=6;
cont=1;
for k=1:length(vector)
    kk=vector(k);
    Famx2=Shaperxy{seg}(:,1);
    Famy2=Shaperxy{seg}(:,2);
    
    angl=linspace(ang,-ang,nst);
    P=[0 rp]; % Invariant point I (see Litvin p.120 fig 6.9.2)
    inim=NaN;
       
    for i=1:length(angl)
        % Motion of the pinion cutter: Rotation
        Rotat1=rotation([Shaperxy{seg}(:,1),Shaperxy{seg}(:,2)], [0 0],angl(i),'degrees');
        Famx2(:,i)=Rotat1(:,1);
        Famy2(:,i)=Rotat1(:,2);
        
        % Normals of the generating rack cutter
        N=LineNormals2D(Rotat1);
               
        % Analytical expression of the normal lines passing through each point
        %--------------------------------------
        % y= Mx+Q
        Xr=Rotat1(:,1); Yr=Rotat1(:,2);
        d=-N(:,1).*Xr-N(:,2).*Yr;
        M=(N(:,2)./N(:,1));
        M(length(M))=M(length(M))*kk;
        Q=Yr-M.*Xr;
        
        [idvert,~]=find(isinf(M)); % for vertical normals
        
        % Intersection of the normal lines of the cutter with the invariant
        % point I (see Litvin p.120 fig 6.9.2)
        yp=P(2);
        xp=(yp-Q)./M;
        xp(idvert)=Xr(idvert); % for vertical normals
        %--------------------------------------
        
        % Find the point of intersection which is closer to I
        dist=sqrt((xp-P(1)).^2+(yp-P(2)).^2);
        [mindist(i),inim(i)]=min(dist);
        if mindist(i) > thresholdI
            inim(i)=NaN;
        end
        
        % Motion of the gear: Rotation
        Rotat2=rotation([Famx2(:,i),Famy2(:,i)], [0 -rg+rp],-angl(i)/gear.params.ratio,'degrees');
        Famx2(:,i)=Rotat2(:,1);
        Famy2(:,i)=Rotat2(:,2);
        
    end % End of the loop on the angular positions for the current segment
        
     if not(all(isnan(inim)))
        % Cartesian coordinates of the generated points
        for i=1:size(angl,2)
            if not(isnan(inim(i)))
                Genxy2{seg}(cont,:)=[Famx2(inim(i),i),Famy2(inim(i),i)];
                cont=cont+1;
            end
        end
     end
    
      % --------------- Plot of the generation ----------------------------------
    figure(fig.params.fighandle); axis equal; hold on; grid on;
    for i=1:8:size(angl,2)
        if i==1
            % plot(Xi,Yi,'r','LineWidth',2)
            plot(Famx2(:,i),Famy2(:,i),'r','LineWidth',2)
            %             xlim([-51.507811143243025,51.507811143243025]);
            %             ylim([75.82073571246437,157.0701539351929])
            set(gcf,'Color',[1 1 1]);
        else
            plot(Famx2(:,i),Famy2(:,i),'k')
        end
    end
end
Genxy2{6}=unique(Genxy2{6},'rows');
Genxy2{6}=sortrows(Genxy2{6});
        % Conversion to polar of seg6
 Genrt2{6}=[];
[Genrt2{6}(:,2),Genrt2{6}(:,1)]=cart2pol(Genxy2{6}(:,1),Genxy2{6}(:,2));

%inner radius correction
 IR=min(Genrt2{4}(:,1));
 for seg=1:7
     Genrt2{seg}(Genrt2{seg}(:,1)<IR,:)=[];
     Genxy2{seg}=[];
     [Genxy2{seg}(:,1),Genxy2{seg}(:,2)]=pol2cart(Genrt2{seg}(:,2),Genrt2{seg}(:,1));
 end
 
for seg=1:7
    i=1;
    Genrt2c=[];
    Genrt2c(1,:)=Genrt2{seg}(1,:);
   for l=2:length(Genrt2{seg}(:,1));
       if abs(Genrt2{seg}(l,1)-Genrt2{seg}(l-1,1))<0.5
          Genrt2c(i+1,:)=Genrt2{seg}(l,:);
          i=i+1;
       end
   end
   Genrt2{seg}=[];
   Genrt2{seg}=Genrt2c;
   Genxy2{seg}=[];
   [Genxy2{seg}(:,1),Genxy2{seg}(:,2)]=pol2cart(Genrt2{seg}(:,2),Genrt2{seg}(:,1));
end

for seg=1:7
 figure(fig.params.fighandle); axis equal; hold on; grid on;     
 plot(Genxy2{seg}(:,1),Genxy2{seg}(:,2),'b','Linewidth',2) 
end
gear.GeneratedInternalGearXY=Genxy2;
gear.GeneratedInternalGearRT=Genrt2;

 figure(701); hold on; axis equal;
 for ik=1:length(Genrt2)
     plot(Genxy2{ik}(:,1),Genxy2{ik}(:,2));
 end

% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end % function CutTeeth end
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function N=LineNormals2D(Vertices,Lines)
% This function calculates the normals, of the line points
% using the neighbouring points of each contour point, and
% forward an backward differences on the end points
%
% N=LineNormals2D(V,L)
%
% inputs,
%   V : List of points/vertices 2 x M
% (optional)
%   Lines : A N x 2 list of line pieces, by indices of the vertices
%         (if not set assume Lines=[1 2; 2 3 ; ... ; M-1 M])
%
% outputs,
%   N : The normals of the Vertices 2 x M
%
% Example, Hand
%  load('testdata');
%  N=LineNormals2D(Vertices,Lines);
%  figure,
%  plot([Vertices(:,1) Vertices(:,1)+10*N(:,1)]',[Vertices(:,2) Vertices(:,2)+10*N(:,2)]');
%
% Function is written by D.Kroon University of Twente (August 2011)
% If no line-indices, assume a x(1) connected with x(2), x(3) with x(4) ...
if(nargin<2)
    Lines=[(1:(size(Vertices,1)-1))' (2:size(Vertices,1))'];
end
% Calculate tangent vectors
DT=Vertices(Lines(:,1),:)-Vertices(Lines(:,2),:);
% Make influence of tangent vector 1/Distance
% (Weighted Central Differences. Points which are closer give a
% more accurate estimate of the normal)
LL=sqrt(DT(:,1).^2+DT(:,2).^2);
DT(:,1)=DT(:,1)./max(LL.^2,eps);
DT(:,2)=DT(:,2)./max(LL.^2,eps);
D1=zeros(size(Vertices)); D1(Lines(:,1),:)=DT;
D2=zeros(size(Vertices)); D2(Lines(:,2),:)=DT;
D=D1+D2;
% Normalize the normal
LL=sqrt(D(:,1).^2+D(:,2).^2);
N(:,1)=-D(:,2)./LL;
N(:,2)= D(:,1)./LL;
end
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function rotated_coords = rotation(input_XY,center,anti_clockwise_angle,varargin)
degree = 1; %Radians : degree = 0; Default is calculations in degrees

% Process the inputs
if length(varargin) ~= 0
    for n = 1:1:length(varargin)
        if strcmp(varargin{n},'degree')
            degree = 1;
        elseif strcmp(varargin{n},'radians')
            degree = 0;
        end
    end
    clear n;
end
[r,c] = size(input_XY);
if c ~= 2
    error('Not enough columns in coordinates XY ');
end
[r,c] = size(center);
if (r~=1 & c==2) | (r==1 & c~=2)
    error('Error in the size of the "center" matrix');
end

% Format the coordinate of the center of rotation
center_coord = input_XY;
center_coord(:,1) = center(1);
center_coord(:,2) = center(2);

% Turns the angles given to be such that the +ve is anti-clockwise and -ve is clockwise
anti_clockwise_angle = -1*anti_clockwise_angle;
% if in degrees, convert to radians because that's what the built-in functions use.
if degree == 1
    anti_clockwise_angle = deg2rad(anti_clockwise_angle);
end

%Produce the roation matrix
rotation_matrix = [cos(anti_clockwise_angle),-1*sin(anti_clockwise_angle);...
    sin(anti_clockwise_angle),cos(anti_clockwise_angle)];
%Calculate the final coordinates
rotated_coords = ((input_XY-center_coord) * rotation_matrix)+center_coord;

end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [invol]=involSegm(RackpointsCell,rack)
% rack base 8 segmenti
% 3 possibili modifiche addizionali:
% tip fillet +2
% semitop +2
% protuberance +2

% full fillet -2

% Check if full fillet is present --------------
if rack.rhoamax == rack.rhoa
    ff=1;
else
    ff=0;
end

% Check if tip radius is present --------------
if rack.rhof > 0
    tipr=1;
else
    tipr=0;
end

% Check if semitop is present --------------
if rack.alphakP0>rack.alpha && rack.hfP0>0
    semitop=1;
else
    semitop=0;
end

% Check if protuberance is present --------------
if rack.alphaprP0>0 && rack.alphaprP0<rack.alpha
    protu=1;
else
    protu=0;
end

if ff == 0 % Non full fillet cases %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if size(RackpointsCell,2) == 14
        % tutto non full fillet
        invol = [4 11];
        
    elseif size(RackpointsCell,2) == 8
        % niente ma non full fillet
        invol = [3 6];
        
    elseif size(RackpointsCell,2) == 10
        % C' una sola delle 3
        if tipr || semitop
            invol=[3 8];
        elseif protu
            invol=[4 7];
        end
        
    elseif size(RackpointsCell,2) == 12
        % Ci sono due delle 3
        if tipr && semitop
            invol=[3 10];
        elseif tipr && protu
            invol=[4 9];
        elseif semitop && protu
            invol=[4 9];
        end
        
    end
    
elseif ff == 1 % FULL fillet cases %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    if size(RackpointsCell,2) == 6
        % niente ma full fillet
        invol = [ 2 5];
    elseif size(RackpointsCell,2) == 8
        % C' una sola delle 3
        if tipr || semitop
            invol=[2 7];
        elseif protu
            invol=[3 6];
        end
    elseif size(RackpointsCell,2) == 10
        % Ci sono due delle 3
        if tipr && semitop
            invol=[2 9];
        elseif tipr && protu
            invol=[3 8];
        elseif semitop && protu
            invol=[3 8];
        end
        
    elseif size(RackpointsCell,2) == 12
        % tutto full fillet
        invol = [3 10];
        
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end % FUNCTION END
% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%