function [gear,mating] = PinionInputParameters

gear=struct;

% definizione numero ruota
% gear.number=1; 
%--------------------------------------------------------------------------
% Come si pu fare per fargli uscire da qua il gear.number in funzione
% della ruota che considera?
%--------------------------------------------------------------------------

%% Basic data

% Young 's module[N/mm^2] 
gear.params.E=2.1e+005;

% Poisson's coefficient [-]
gear.params.v=0.3; 

% Yield strength Rp02 [MPa] 
gear.params.Rp02=500;

% Density rho [ton/mm3]
gear.params.rho=7.85e-9; % manca la densit del material nei parametri

% Number of teeth [-]
gear.params.z=48;

% Normal module [mm]
gear.params.mn=3.125;

% Nominal helix angle []
gear.params.beta=-0*pi/180;

% Normal pressure angle [deg]
gear.params.alfan=20;

% Teeth facewidth [mm]
gear.params.b=6.35;

% Gear body feacewidth [mm]
gear.params.w=6.35;

% Shaft external radius [mm]
gear.params.r_shaft_e=35;

% Shaft internal radius [mm]
gear.params.r_shaft_i=0;

% Rim depth (distance between root radius and gear body external radius)
gear.params.profondita_rim=5;

% Shaft length
gear.params.l_shaft=50;

% shift coefficient correction
gear.params.shift_coeff = 0;

% root fillet coefficient
gear.params.fillet_coeff = 0.38;

% coefficiente addendum (base 1)
gear.params.Cha = 1;

% coefficiente dedendum (base 1.25)
gear.params.Chf = 1.25;

% gear ratio between pinion and internal involute gear
gear.params.ratio = 8;

%% Tooth profile modifications (TPM)

% Tip relief
% Type_of_Tip_relief_1: funzione rimozione materiale su singola fettina
% TipReliefFacewidth (Delta_La): funzione selezione nodi lungo la larghezza di fascia
% TipMaxMaterial (Ca): funzione massima rimozione di materiale lungo la fascia
gear.params.Tip_relief = 'Yes'; % attualmente non utilizzato in TipRelief

gear.params.Type_of_Tip_relief_1 = 'Linear'; % 'Linear', 'Parabolic'
gear.params.TipReliefFacewidth = 'Standard'; % 'Standard', 'Linear', 'Parabolic'
gear.params.TipMaxMaterial = 'Standard'; % 'Standard', 'Linear', 'Parabolic'

gear.params.Ca1 = 0.2861;                     % in z = 0
gear.params.Delta_La1 = 0.2861;                % in z = 0
gear.params.Ca2 = 0.2861;                     % in z = gear.params.b
gear.params.Delta_La2 = 0.2861;                % in z = gear.params.b

% Helix deviation
gear.params.Chb = 0; % positivo toglie materiale dalla prima fettina

% Crowning
gear.params.delta_Lc1 = 0.3; % in 0 <= z < b/2
gear.params.delta_Lc2 = []; % in b/2 < z <= b (se [] simmetrico)
gear.params.zLc1 = 80; % percentuale lettura delta_Lc1
gear.params.zLc2 = []; % (se [] simmetrico)
gear.params.zL1 = 0; % inizio crowning a zL1 millimetri dalla mezzeria
gear.params.zL2 = []; % (se [] simmetrico)

% End Relief
gear.params.Delta_Ler1 = 0; % in 0 <= z < b/2
gear.params.Delta_Ler2 =[]; % in b/2 < z <= b (se [] simmetrico)
gear.params.zLerptg1 = 80; % percentuale lettura delta_Lc1
gear.params.zLerptg2 = []; % (se [] simmetrico)
gear.params.zLer1 = 6; % inizio crowning a zL1 millimetri dalla mezzeria
gear.params.zLer2 = []; % (se [] simmetrico)

% Involute crowning & Profile correction
gear.params.Da = 73.448; % Control form diameter (lower)
gear.params.Dx = 82.506; % Final control diameter (higher)
gear.params.Calfa = 0; % Involute crowning [mm]
gear.params.CHalfa = 0; % Profile correction [mm]

% Misalignment
gear.mis.origin = [0,-104;0,-104]; %[0,-104]; % [x,y ; x,y][mm] could be a point of the gear or a bearing
gear.mis.angle = [0 0];       % [angx; angy] degree
gear.mis.axis = 'xy';        % 'x','y','xy' axis of misalignment (see Niemann page 81)   

%% Tolerances

% 1) Tip circle deviation
gear.params.TCDev = 0; % 1 to activate tolerance TCDevVal by inserting table values (i.e. h7), 0 to insert values by hand in the GUI
mating.params.TCDev_type = 4; % 1 Upper, 2 Lower, 3 Mean, 4 by hand (both for pinion and gear)
if gear.params.TCDev == 1 % choose tolerance with ISO
    
gear.params.TCDevIT = 7; % quality it (it1,...,it18)

% gear.params.TCDevVal choose between:
% a  = 1        n  = 19
% b  = 2        p  = 20
% c  = 3        r  = 21
% cd = 4        s  = 22
% d  = 5        t  = 23
% e  = 6        u  = 24
% ef = 7        v  = 25
% f  = 8        x  = 26
% fg = 9        y  = 27
% g  = 10       z  = 28
% h  = 11       za = 29
% js = 12       zb = 30
% j  = 13       zc = 31
% k  = 16
% m  = 18

gear.params.TCDevVal = 4;

if gear.params.TCDevVal == 13
    if gear.params.TCDevIT == 5|| gear.params.TCDevIT == 6
    gear.params.TCDevVal = 13;        
    elseif gear.params.TCDevIT == 7
       gear.params.TCDevVal = 14;
    elseif gear.params.TCDevIT == 8
       gear.params.TCDevVal = 15;
    else
        warning('The quality IT inserted is not compatible with the deviation choosen!')
      gear.params.TCDeves = 0;
      gear.params.TCDevei = 0;
      gear.params.TCDev = 0;
    end
elseif gear.params.TCDevVal == 16
    if gear.params.TCDevIT >= 4 && gear.params.TCDevIT <= 7
      gear.params.TCDevVal = 16;
    elseif gear.params.TCDevIT <= 3 || gear.params.TCDevIT >= 8
      gear.params.TCDevVal = 17;
    end
end

else % insert values by hand
    
    gear.params.TCDeves = 0;
    gear.params.TCDevei = 0;
    
end
 
% 2) Tooth thickness deviation
gear.params.TTDev = 2;      % 1 values from table inside backlash, 2 Asn by hand, 3 jtmin/max by hand, 4 jnmin/max by hand

if gear.params.TTDev == 1
    
% thicktoll: values from 21 to 30
% insert input value 1 --> 21, 10 --> 30
gear.params.thicktoll = 7;

% thickall choose between:
% a  = 1        cd = 6
% ab = 2        d  = 7
% b  = 3        e  = 8
% bc = 4        f  = 9
% c  = 5        g  = 10
%               h  = 11
gear.params.thickall = 6;

elseif gear.params.TTDev == 2
    gear.params.Asne = 0; % [um]
    gear.params.Asni = 0; % [um]
    
elseif gear.params.TTDev == 3
    gear.params.jtmin = 0; % [um]
    gear.params.jtmax = 0; % [um]
    
elseif gear.params.TTDev == 4
    gear.params.jnmin = 6; % [um] 
    gear.params.jnmax = 12; % [um]

end
    


% 3) Tooth thickness tolerance (to choose which backlash to take for
% calculations, same type of value taken both for pinion and gear)
% mating.params.backlash_type = 1 Upper, 2 Lower, 3 Mean, 4 by hand
mating.params.backlash_type = 3;

    
% 4) Shaft center distance tolerance
mating.params.CDDev = 0; % 0 by hand, 1 from table
if mating.params.CDDev == 1
% CDtoll: values from js5 to js11
% insert input value 1 --> js5, 7 --> js11
mating.params.CDtoll = 3;
elseif mating.params.CDDev == 0
    mating.params.Aamin = 0;
    mating.params.Aamax = 0;
    mating.params.Aa_ampl = 0;
end    

% NB: shaft accuracy indications from table 1 in DIN 3964 mut be added;
% these accuracies are useful to know the values of fSigbeta and fSigdelta
% that are used in Misalignment.
