clear all
close all
clc

%% Defining design parameters
%Normal Pressure Angle
PhiN=20;
%Module
m=3;
%Helix Angle
Psi=30;
%Number of teeth on gear
N=17;
%Addendum of gear
a=1*m;
%Dedendum of gear
b=1.25*m;
%Circular pitch
p=m*pi();
%Gear Thickness
t=50;
%Tangential Pressure Angle
PhiT=atand(tand(PhiN)/cosd(Psi));
%Radius
R=N*m/2;

%% Defining the rack
Rack1 = [ 0               p/4-b*tand(PhiT)    p/4+a*tand(PhiT)    3*p/4-a*tand(PhiT)  3*p/4+b*tand(PhiT)  p;
         -b              -b                   a                   a                  -b                  -b;
          t/2             t/2                 t/2                 t/2                 t/2                 t/2;
          1               1                   1                   1                   1                   1];
Rack2 = [-t*tand(Psi)     p/4-b*tand(PhiT)-t*tand(Psi)    p/4+a*tand(PhiT)-t*tand(Psi)    3*p/4-a*tand(PhiT)-t*tand(Psi)  3*p/4+b*tand(PhiT)-t*tand(Psi)  p-t*tand(Psi);
         -b              -b                              a                                a                              -b                              -b            ;
         -t/2            -t/2                            -t/2                            -t/2                            -t/2                            -t/2          ;
          1               1                               1                               1                               1                               1            ];

      
%% Trajectory matrix
TrajectoryMatrix1=zeros(4,6,300);    %500 angle iterations.
TrajectoryMatrix2=zeros(4,6,300);    %500 angle iterations.

for i=1:300
     Phi=i/2-100;
         
     M12=[ cosd(Phi)  sind(Phi)  0  R*(sind(Phi)-degtorad(Phi)*cosd(Phi));
          -sind(Phi)  cosd(Phi)  0  R*(cosd(Phi)+degtorad(Phi)*sind(Phi));
           0          0          1  0                                    ;
           0          0          0  1                                    ];
           

    TrajectoryMatrix1(:,:,i)=M12*Rack1;
    TrajectoryMatrix2(:,:,i)=M12*Rack2;
end


%% Plotting
 plot3(TrajectoryMatrix1(1,:,1),TrajectoryMatrix1(2,:,1),TrajectoryMatrix1(3,:,1),'red')
 hold on
 plot3(TrajectoryMatrix2(1,:,1),TrajectoryMatrix2(2,:,1),TrajectoryMatrix2(3,:,1),'red')
 hold on
 for i=1:5
 fill3([TrajectoryMatrix1(1,i,1) TrajectoryMatrix1(1,i+1,1) TrajectoryMatrix2(1,i+1,1) TrajectoryMatrix2(1,i,1)], [TrajectoryMatrix1(2,i,1) TrajectoryMatrix1(2,i+1,1) TrajectoryMatrix2(2,i+1,1) TrajectoryMatrix2(2,i,1)], [TrajectoryMatrix1(3,i,1) TrajectoryMatrix1(3,i+1,1) TrajectoryMatrix2(3,i+1,1) TrajectoryMatrix2(3,i,1)], 'r')
 end
 
 for j=2:300
     plot3(TrajectoryMatrix1(1,:,j),TrajectoryMatrix1(2,:,j),TrajectoryMatrix1(3,:,j),'black')
     hold on
     plot3(TrajectoryMatrix2(1,:,j),TrajectoryMatrix2(2,:,j),TrajectoryMatrix2(3,:,j),'black')
     hold on
     for i=1:5
     fill3([TrajectoryMatrix1(1,i,j) TrajectoryMatrix1(1,i+1,j) TrajectoryMatrix2(1,i+1,j) TrajectoryMatrix2(1,i,j)], [TrajectoryMatrix1(2,i,j) TrajectoryMatrix1(2,i+1,j) TrajectoryMatrix2(2,i+1,j) TrajectoryMatrix2(2,i,j)], [TrajectoryMatrix1(3,i,j) TrajectoryMatrix1(3,i+1,j) TrajectoryMatrix2(3,i+1,j) TrajectoryMatrix2(3,i,j)], 'b')
     end
 end
  axis equal
